==> nonebot_plugin_githubcard-0.2.0.tar.gz: nonebot_plugin_githubcard-0.2.0/README.md <==
<div align="center">
  <a href="https://nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-githubcard

_✨ 检测GitHub仓库链接并自动发送卡片信息（适用于Onebot V11）✨_

<a href="./LICENSE">
    <img src="https://camo.githubusercontent.com/6849e28a50157229c6a1426570610ecbe589c68bd7c806f4f7513d7265db8cf2/68747470733a2f2f696d672e736869656c64732e696f2f6769746875622f6c6963656e73652f6e6f6e65706c7567696e2f6e6f6e65626f742d706c7567696e2d706574706574" alt="license">
</a><img src="https://img.shields.io/badge/nonebot-2.0.0+-red.svg" alt="NoneBot">
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 📖 介绍

检测GitHub仓库链接并自动发送卡片信息

## 💿 安装

<details>
<summary>使用PIP安装</summary>


    pip install nonebot-plugin-githubcard
</details>

<details>
<summary>克隆至本地安装</summary>


    git clone https://github.com/ElainaFanBoy/nonebot_plugin_githubcard.git
</details>

## ⚙️ 配置

在 nonebot2 项目的`.env`文件中添加下表中的必填配置

| 配置项 | 必填 | 默认值 | 说明 |
|:-----:|:----:|:----:|:----:|
| github_token | 否 | 无 | github_token = ghp_xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx |
| github_type | 否 | 0 | github图片样式(0为默认样式，1为opengraph样式) |

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 说明 |
|:-----:|:----:|:----:|:----:|
| https://github.com/xxx/xxx | 所有人 | 否 | GitHub仓库链接 |
### 效果图

<div align="left">
  <img src="https://s1.vika.cn/space/2023/05/21/f6b1a891001346fe90ac398eb2f2f26a?attname=test.png"/>
  <img src="https://opengraph.githubassets.com/githubcard/nonebot/nonebot2"/>
</div>

==> nonebot_plugin_githubcard-0.2.1.tar.gz: nonebot_plugin_githubcard-0.2.1/README.md <==
<div align="center">
  <a href="https://nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-githubcard

_✨ 检测GitHub仓库链接并自动发送卡片信息（适用于Onebot V11）✨_

<a href="./LICENSE">
    <img src="https://camo.githubusercontent.com/6849e28a50157229c6a1426570610ecbe589c68bd7c806f4f7513d7265db8cf2/68747470733a2f2f696d672e736869656c64732e696f2f6769746875622f6c6963656e73652f6e6f6e65706c7567696e2f6e6f6e65626f742d706c7567696e2d706574706574" alt="license">
</a><img src="https://img.shields.io/badge/nonebot-2.0.0+-red.svg" alt="NoneBot">
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 📖 介绍

检测GitHub仓库链接并自动发送卡片信息

## 💿 安装

<details>
<summary>使用PIP安装</summary>


    pip install nonebot-plugin-githubcard
</details>

<details>
<summary>克隆至本地安装</summary>


    git clone https://github.com/ElainaFanBoy/nonebot_plugin_githubcard.git
</details>

## ⚙️ 配置

在 nonebot2 项目的`.env`文件中添加下表中的必填配置

| 配置项 | 必填 | 默认值 | 说明 |
|:-----:|:----:|:----:|:----:|
| github_token | 否 | 无 | github_token = ghp_xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx |
| github_type | 否 | 0 | github图片样式(0为socialify样式，1为opengraph样式) |

## 🎉 使用
### 指令表
| 指令 | 权限 | 需要@ | 说明 |
|:-----:|:----:|:----:|:----:|
| https://github.com/xxx/xxx | 所有人 | 否 | GitHub仓库链接 |
### 效果图

<div align="left">
  
  socialify样式：
  
  <img src="https://socialify.git.ci/nonebot/nonebot2/image?description=1&font=Rokkitt&forks=1&issues=1&language=1&logo=https%3A%2F%2Favatars.githubusercontent.com%2Fu%2F63496654%3Fs%3D200%26v%3D4&name=1&owner=1&pattern=Circuit%20Board&pulls=1&stargazers=1&theme=Light" width="600"/>
  
  opengraph样式：
  
  <img src="https://opengraph.githubassets.com/githubcard/nonebot/nonebot2" width="600"/>
</div>
